<?php
App::uses('EvBlogAppController', 'EvBlog.Controller');
App::uses('CustomEmail', 'Lib');

class BlogCommentsController extends EvBlogAppController
{
	public function beforeFilter()
	{
		$this->Auth->allow('post_comment');

		return parent::beforeFilter();
	}

	protected function _adminFormFields()
	{
		$fields = parent::_adminFormFields();
		unset($fields['BlogComment.blog_post_id'], $fields['BlogComment.parent_id']);
		$fields['BlogComment.comment']['type'] = 'text_plain';
		$fields['BlogComment.comment']['style'] = 'width: 360px;height:150px;';


		return $fields;
	}


	public function admin_delete($id)
	{
		$Model = $this->{$this->modelClass};

		$data = $Model->findById($id);

		$Model->delete($id);

		$this->Session->setFlash(array(
			'title' => 'Comment deleted',
			'description' => 'Comment has been successfully deleted!'
		), 'flash_success');

		$route = RouterUtil::getItemRoute('EvBlog', 'BlogPost');
		$route['action'] = 'edit';
		$route['admin'] = true;
		$route[] = $data['BlogComment']['blog_post_id'];

		return $this->redirect($route);
	}

	public function admin_edit($id = null) {

		$Model = $this->{$this->modelClass};

		$data = $Model->findById($id);

		$route = RouterUtil::getItemRoute('EvBlog', 'BlogPost');
		$route['action'] = 'edit';
		$route['admin'] = true;
		$route[] = $data['BlogComment']['blog_post_id'];

		$this->adminRedirect = $route;

		parent::admin_edit($id);
	}


	public function post_comment() {

		if ($this->request->is('post') && ! empty($this->request->data)) {

			$Model = $this->{$this->modelClass};

			if (isset($this->request->data['BlogComment']['email_confirm']) && ! empty($this->request->data['BlogComment']['email_confirm'])) {

				// spam field was field in, redirect them to the login page, will display success message
				$this->Session->setFlash(
					'Comment has been posted.',
					'EvBlog.message',
					array('class' => 'ev-blog__message--success'),
					'blog-comment'
				);

			} else {

				if (! isset($this->request->data['BlogComment']['parent_id']) || empty($this->request->data['BlogComment']['parent_id'])) {

					$this->request->data['BlogComment']['parent_id'] = null;
				}

				if (isset($this->request->data['BlogComment']['comment_id']) && empty($this->request->data['BlogComment']['comment_id'])) {

					if ($Model->saveAll($this->request->data)) {

						$this->Session->setFlash(
							'Thanks, your comment has been posted!',
							'EvBlog.message',
							array('class' => 'ev-blog__message--success'),
							'blog-comment'
						);

						$post = $Model->BlogPost->findById($this->request->data['BlogComment']['blog_post_id']);

						// send email to admin informing of new comment
						$email = new CustomEmail('sendgrid');

						$email->theme('Site');
						$email->template('EvBlog.new-comment');
						$email->emailFormat('html');
						$email->to(Configure::read('SiteSetting.general.admin_email'));
						$email->from(array(Configure::read('SiteSetting.general.admin_email') => Configure::read('SiteSetting.general.site_title')));
						$email->subject('New blog comment posted');
						$email->viewVars(array(
							'post' => $post,
							'comment_id' => $Model->id
						));
						$email->helpers(array(
								'Html',
								'Routable.Route'
						));
						$email->send();

					} else {

						$this->Session->setFlash(
							'There was an error posting your comment, please try again.',
							'EvBlog.message',
							array('class' => 'ev-blog__message--error'),
							'blog-comment'
						);
					}
				}
			}
		}

		$this->redirect(
			$this->referer() . '#blog-comments'
		);
	}

}
